<?php
App::import('Helper', 'Form');
class AppFormHelper extends FormHelper {
	var $helpers = array('Html', 'Javascript');
	/**
	 * @example of use
	 * 		echo $appForm->input('title', array());
	 * @example of output
	 * 		<tr>
	 *			<th>Title</th>
	 *			<td>
	 *				<div class="input text required">
	 *					<input name="data[Schedule][title]" type="text" maxlength="100" id="ScheduleTitle" />
	 *				</div>
	 *			</td>
	 *		</tr>
	 *
	 */
	function input($fieldName, $options = array()) {
		$label = null;
		if(!empty($options['label'])) {
			$label = $options['label'];
		}
		$options['label'] = false;
		$view =& ClassRegistry::getObject('view');
		$this->setEntity($fieldName);
		$model =& ClassRegistry::getObject($this->model());
		$type = $model->getColumnType($this->field());
		if($type == 'datetime') {
			$options = $this->setDatetimeOptions($options);
		}

		$out = '';
		$out .= '<tr>';
		$out .= '<th>';
		$out .= parent::label($fieldName, $label);
		$out .= '</th>';
		$out .= '<td>';
		$out .= parent::input($fieldName, $options);
		$out .= '</td>';
		$out .= '</tr>';

		return $out;
	}

	/**
	 * @example of use
	 * 		echo $appForm->create('Schedule');
	 * @example of output
	 * 		<form >
	 *			<tabel class="form">
	 *
	 */
	function create($model = null, $options = array()) {
		$out = parent::create($model, $options);
		$out .= '<table class="form">';
		return $out;
	}
	/**
	 * @example of use
	 * 		echo $appForm->end();
	 * @example of output
	 * 			</table>
	 *		</form>
	 *
	 */
	function end($options = null) {
		$out = '</table>';
		$out .= parent::end($options);
		return $out;
	}

	function setDatetimeOptions($options) {
		$locale = Configure::read('Config.language');
		switch($locale) {
		case 'ja' :
			$options = array_merge(array(
					'dateFormat'=>'YMD', // 年月日順
					'timeFormat'=>24, 	 // 24時間方式
					'separator'=>'',	 // 日付の区切り文字
					'interval'=>10		 // 10分間隔
				)
				,$options);
			break;
		}
		return $options;
	}
	function select($fieldName, $options = array(), $selected = null, $attributes = array(), $showEmpty = '') {
		$locale = Configure::read('Config.language');
		switch($locale) {
		case 'ja' :
			$type = split('\\.', $fieldName);
			switch(array_pop($type)) {
			case 'year' :
				foreach($options as $key=>$value) {
					$options[$key] = $value.'年';
				}
				break;
			case 'day' :
				foreach($options as $key=>$value) {
					$options[$key] = $value.'日';
				}
				break;
			}
			break;
		}
		return parent::select($fieldName, $options, $selected, $attributes, $showEmpty);
	}
	function delete_button($url) {
		$out = $this->button(__('Delete',true), 
			array('onclick'=>'javascript:delete_submit(\''.__('Are you sure you want to delete',true).'\',\''.$url.'\');'));
		$script = '
			function delete_submit(confirm, url) {
				if(window.confirm(confirm)) {
					location.href = url;
				}
			} 
		';
		$this->Javascript->codeBlock($script,array('inline'=>false));
		return $out;
	}
	function printDatetime($dt) {
		$time = mktime($dt['hour'], $dt['min'], 0, $dt['month'], $dt['day'], $dt['year']);
		return date(__("D, M jS Y, H:i",true), $time);
	}

}
?>
